@@ -42,7 +42,7 @@ class Swift(monasca_setup.detection.ServicePlugin):
 
     """
 
-    def __init__(self, template_dir, overwrite=True):
+    def __init__(self, template_dir, overwrite=True, args=None):
         service_params = {
             'template_dir': template_dir,
             'overwrite': overwrite,
